@@ -13,7 +13,7 @@ use HTTP::Request::Common;
 use Try::Tiny qw( try catch finally );
 use Carp 'croak';
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 has json => ( is => 'ro', default => sub { JSON->new } );
 has ua   => (
@@ -47,11 +47,11 @@ sub login {
     croak('Must provide "user" and "passwd" values to login() or new()')
         unless ( $self->user and $self->passwd );
 
-    my $form = ( HTML::Form->parse( $self->ua->request(
-        HTTP::Request->new( 'GET', 'https://mail.google.com/tasks/ig' )
-    ) ) )[0];
-
+    my $form = ( HTML::Form->parse(
+        $self->ua->request( HTTP::Request->new( 'GET', 'https://mail.google.com/tasks/ig' ) )
+    ) )[0];
     $form->value( 'Email', $self->user );
+    $form = ( HTML::Form->parse( $self->ua->request( $form->click ) ) )[0];
     $form->value( 'Passwd', $self->passwd );
 
     my $res = $self->ua->request( $form->click );
@@ -423,7 +423,7 @@ Google::Tasks - Manipulate Google/GMail Tasks
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Google-Tasks.svg)](https://travis-ci.org/gryphonshafer/Google-Tasks)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Google-Tasks/badge.png)](https://coveralls.io/r/gryphonshafer/Google-Tasks)
@@ -794,6 +794,14 @@ L<Travis CI|https://travis-ci.org/gryphonshafer/Google-Tasks>
 
 L<Coveralls|https://coveralls.io/r/gryphonshafer/Google-Tasks>
 
+=item *
+
+L<CPANTS|http://cpants.cpanauthors.org/dist/Google-Tasks>
+
+=item *
+
+L<CPAN Testers|http://www.cpantesters.org/distro/G/Google-Tasks.html>
+
 =back
 
 =for Pod::Coverage BUILD is_authed json passwd ua user
